"""
Random User-Agent
Copyright: 2022 Ekin Karadeniz (github.com/iamdual)
License: Apache License 2.0 
"""

devices = ('desktop', 'mobile')

platforms = ('windows', 'macos', 'ios', 'linux', 'android')
platforms_desktop = ('windows', 'macos', 'linux')
platforms_mobile = ('ios', 'android')

browsers = ('chrome', 'edge', 'firefox', 'safari')
